@@ -8,19 +8,25 @@ const (
 	IMAGE       = "image"
 	TCP_STREAM  = "tcp_stream"
 	UDP_PAYLOAD = "udp_payload"
+	LINK_FRAME  = "link_frame"
 
 	RAW  = "raw"
 	JSON = "json"
+	BSON = "bson"
 
-	DNS             = "dns"
-	DNS_TCP         = "dns_tcp"
-	ETHER8023_FRAME = "ether8023_frame"
-	SLL_PACKET      = "sll_packet"
-	SLL2_PACKET     = "sll2_packet"
-	IPV4_PACKET     = "ipv4_packet"
-	UDP_DATAGRAM    = "udp_datagram"
-	TCP_SEGMENT     = "tcp_segment"
-	ICMP            = "icmp"
+	DNS                = "dns"
+	DNS_TCP            = "dns_tcp"
+	ETHER8023_FRAME    = "ether8023_frame"
+	BSD_LOOPBACK_FRAME = "bsd_loopback_frame"
+	SLL_PACKET         = "sll_packet"
+	SLL2_PACKET        = "sll2_packet"
+	IPV4_PACKET        = "ipv4_packet"
+	UDP_DATAGRAM       = "udp_datagram"
+	TCP_SEGMENT        = "tcp_segment"
+	ICMP               = "icmp"
+
+	ELF = "elf"
+	AR  = "ar"
 
 	AAC_FRAME           = "aac_frame"
 	ADTS                = "adts"
@@ -30,7 +36,6 @@ const (
 	AV1_FRAME           = "av1_frame"
 	AV1_OBU             = "av1_obu"
 	BZIP2               = "bzip2"
-	ELF                 = "elf"
 	EXIF                = "exif"
 	FLAC                = "flac"
 	FLAC_FRAME          = "flac_frame"
@@ -187,7 +192,17 @@ type MP3FrameOut struct {
 	ChannelModeIndex int
 }
 
-type UDPDatagramIn struct {
+type In struct {
+	SourcePort      int
+	DestinationPort int
+}
+
+type LinkFrameIn struct {
+	Type         int
+	LittleEndian bool // pcap endian etc
+}
+
+type UDPPayloadIn struct {
 	SourcePort      int
 	DestinationPort int
 }
@@ -196,3 +211,13 @@ type TCPStreamIn struct {
 	SourcePort      int
 	DestinationPort int
 }
+
+type X86_64In struct {
+	Base      int64
+	SymLookup func(uint64) (string, uint64)
+}
+
+type ARM64In struct {
+	Base      int64
+	SymLookup func(uint64) (string, uint64)
+}
