@@ -11,9 +11,8 @@ import (
 	"fmt"
 	"io"
 	"io/fs"
-	"io/ioutil"
 	"math/big"
-	"path/filepath"
+	"path"
 	"strconv"
 	"strings"
 	"time"
@@ -55,13 +54,12 @@ func init() {
 		return []Function{
 			{"_readline", 0, 2, i.readline, nil},
 			{"eval", 1, 2, nil, i.eval},
-			{"stdin", 0, 0, nil, i.makeStdioFn(i.os.Stdin())},
-			{"stdout", 0, 0, nil, i.makeStdioFn(i.os.Stdout())},
-			{"stderr", 0, 0, nil, i.makeStdioFn(i.os.Stderr())},
+			{"_stdin", 0, 0, nil, i.makeStdioFn(i.os.Stdin())},
+			{"_stdout", 0, 0, nil, i.makeStdioFn(i.os.Stdout())},
+			{"_stderr", 0, 0, nil, i.makeStdioFn(i.os.Stderr())},
 			{"_extkeys", 0, 0, i._extKeys, nil},
 			{"_exttype", 0, 0, i._extType, nil},
 			{"_global_state", 0, 1, i.makeStateFn(i.state), nil},
-			{"_registry", 0, 0, i._registry, nil},
 			{"history", 0, 0, i.history, nil},
 			{"_display", 1, 1, nil, i._display},
 			{"_can_display", 0, 0, i._canDisplay, nil},
@@ -539,86 +537,6 @@ func (i *Interp) makeStateFn(state *interface{}) func(c interface{}, a []interfa
 	}
 }
 
-func (i *Interp) _registry(c interface{}, a []interface{}) interface{} {
-	uniqueFormats := map[string]decode.Format{}
-
-	groups := map[string]interface{}{}
-	formats := map[string]interface{}{}
-
-	for fsName := range i.registry.Groups {
-		var group []interface{}
-
-		for _, f := range i.registry.MustGroup(fsName) {
-			group = append(group, f.Name)
-			if _, ok := uniqueFormats[f.Name]; ok {
-				continue
-			}
-			uniqueFormats[f.Name] = f
-		}
-
-		groups[fsName] = group
-	}
-
-	for _, f := range uniqueFormats {
-		vf := map[string]interface{}{
-			"name":        f.Name,
-			"description": f.Description,
-			"probe_order": f.ProbeOrder,
-			"root_name":   f.RootName,
-			"root_array":  f.RootArray,
-		}
-
-		var dependenciesVs []interface{}
-		for _, d := range f.Dependencies {
-			var dNamesVs []interface{}
-			for _, n := range d.Names {
-				dNamesVs = append(dNamesVs, n)
-			}
-			dependenciesVs = append(dependenciesVs, dNamesVs)
-		}
-		if len(dependenciesVs) > 0 {
-			vf["dependencies"] = dependenciesVs
-		}
-		var groupsVs []interface{}
-		for _, n := range f.Groups {
-			groupsVs = append(groupsVs, n)
-		}
-		if len(groupsVs) > 0 {
-			vf["groups"] = groupsVs
-		}
-
-		if f.Files != nil {
-			files := map[string]interface{}{}
-
-			entries, err := f.Files.ReadDir(".")
-			if err != nil {
-				return err
-			}
-
-			for _, e := range entries {
-				f, err := f.Files.Open(e.Name())
-				if err != nil {
-					return err
-				}
-				b, err := ioutil.ReadAll(f)
-				if err != nil {
-					return err
-				}
-				files[e.Name()] = string(b)
-			}
-
-			vf["files"] = files
-		}
-
-		formats[f.Name] = vf
-	}
-
-	return map[string]interface{}{
-		"groups":  groups,
-		"formats": formats,
-	}
-}
-
 func (i *Interp) makeStdioFn(t Terminal) func(c interface{}, a []interface{}) gojq.Iter {
 	return func(c interface{}, a []interface{}) gojq.Iter {
 		if c == nil {
@@ -686,6 +604,51 @@ func (i *Interp) _canDisplay(c interface{}, a []interface{}) interface{} {
 	return ok
 }
 
+type pathResolver struct {
+	prefix string
+	open   func(filename string) (io.ReadCloser, error)
+}
+
+func (i *Interp) lookupPathResolver(filename string) (pathResolver, bool) {
+	resolvePaths := []pathResolver{
+		{
+			"@builtin/",
+			func(filename string) (io.ReadCloser, error) { return builtinFS.Open(filename) },
+		},
+		{
+			"@config/", func(filename string) (io.ReadCloser, error) {
+				configDir, err := i.os.ConfigDir()
+				if err != nil {
+					return nil, err
+				}
+				return i.os.FS().Open(path.Join(configDir, filename))
+			},
+		},
+		{
+			"", func(filename string) (io.ReadCloser, error) {
+				if path.IsAbs(filename) {
+					return i.os.FS().Open(filename)
+				}
+
+				// TODO: jq $ORIGIN
+				for _, includePath := range append([]string{"./"}, i.includePaths()...) {
+					if f, err := i.os.FS().Open(path.Join(includePath, filename)); err == nil {
+						return f, nil
+					}
+				}
+
+				return nil, &fs.PathError{Op: "open", Path: filename, Err: fs.ErrNotExist}
+			},
+		},
+	}
+	for _, p := range resolvePaths {
+		if strings.HasPrefix(filename, p.prefix) {
+			return p, true
+		}
+	}
+	return pathResolver{}, false
+}
+
 func (i *Interp) Eval(ctx context.Context, c interface{}, src string, srcFilename string, output io.Writer) (gojq.Iter, error) {
 	gq, err := gojq.Parse(src)
 	if err != nil {
@@ -746,68 +709,68 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, src string, srcFilenam
 			}
 			filename = filename + ".jq"
 
-			pathPrefixes := []struct {
-				prefix string
-				fn     func(filename string) (io.ReadCloser, error)
-			}{
-				{
-					"@builtin/", func(filename string) (io.ReadCloser, error) {
-						return builtinFS.Open(filename)
-					},
-				},
-				{
-					"@config/", func(filename string) (io.ReadCloser, error) {
-						configDir, err := i.os.ConfigDir()
-						if err != nil {
-							return nil, err
-						}
-						return i.os.FS().Open(filepath.Join(configDir, filename))
-					},
-				},
-				{
-					"", func(filename string) (io.ReadCloser, error) {
-						// TODO: jq $ORIGIN
-
-						if filepath.IsAbs(filename) {
-							return i.os.FS().Open(filename)
-						}
-
-						for _, path := range append([]string{"./"}, i.includePaths()...) {
-							if f, err := i.os.FS().Open(filepath.Join(path, filename)); err == nil {
-								return f, nil
-							}
-						}
-
-						return nil, &fs.PathError{Op: "open", Path: filename, Err: fs.ErrNotExist}
-					},
-				},
+			pr, ok := i.lookupPathResolver(filename)
+			if !ok {
+				return nil, fmt.Errorf("could not resolve path: %s", filename)
 			}
 
-			for _, p := range pathPrefixes {
-				if !strings.HasPrefix(filename, p.prefix) {
-					continue
-				}
+			if q, ok := ni.includeCache[filename]; ok {
+				return q, nil
+			}
 
-				if q, ok := ni.includeCache[filename]; ok {
-					return q, nil
-				}
+			filenamePart := strings.TrimPrefix(filename, pr.prefix)
 
-				filenamePart := strings.TrimPrefix(filename, p.prefix)
-				f, err := p.fn(filenamePart)
-				if err != nil {
-					if !isTry {
-						return nil, err
-					}
-					f = io.NopCloser(&bytes.Buffer{})
+			f, err := pr.open(filenamePart)
+			if err != nil {
+				if !isTry {
+					return nil, err
 				}
-				defer f.Close()
+				f = io.NopCloser(&bytes.Buffer{})
+			}
+			defer f.Close()
 
-				b, err := io.ReadAll(f)
+			b, err := io.ReadAll(f)
+			if err != nil {
+				return nil, err
+			}
+			s := string(b)
+			q, err := gojq.Parse(s)
+			if err != nil {
+				p := queryErrorPosition(s, err)
+				return nil, compileError{
+					err:      err,
+					what:     "parse",
+					filename: filenamePart,
+					pos:      p,
+				}
+			}
+
+			// not identity body means it returns something, threat as dynamic include
+			if q.Term.Type != gojq.TermTypeIdentity {
+				gc, err := gojq.Compile(q, funcCompilerOpts...)
 				if err != nil {
 					return nil, err
 				}
-				s := string(b)
-				q, err := gojq.Parse(s)
+				iter := gc.RunWithContext(context.Background(), nil)
+				var vs []interface{}
+				for {
+					v, ok := iter.Next()
+					if !ok {
+						break
+					}
+					if err, ok := v.(error); ok {
+						return nil, err
+					}
+					vs = append(vs, v)
+				}
+				if len(vs) != 1 {
+					return nil, fmt.Errorf("dynamic include: must output one string, got: %#v", vs)
+				}
+				s, sOk := vs[0].(string)
+				if !sOk {
+					return nil, fmt.Errorf("dynamic include: must be string, got %#v", s)
+				}
+				q, err = gojq.Parse(s)
 				if err != nil {
 					p := queryErrorPosition(s, err)
 					return nil, compileError{
@@ -817,67 +780,30 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, src string, srcFilenam
 						pos:      p,
 					}
 				}
-
-				// not identity body means it returns something, threat as dynamic include
-				if q.Term.Type != gojq.TermTypeIdentity {
-					gc, err := gojq.Compile(q, funcCompilerOpts...)
-					if err != nil {
-						return nil, err
-					}
-					iter := gc.RunWithContext(context.Background(), nil)
-					var vs []interface{}
-					for {
-						v, ok := iter.Next()
-						if !ok {
-							break
-						}
-						if err, ok := v.(error); ok {
-							return nil, err
-						}
-						vs = append(vs, v)
-					}
-					if len(vs) != 1 {
-						return nil, fmt.Errorf("dynamic include: must output one string, got: %#v", vs)
-					}
-					s, sOk := vs[0].(string)
-					if !sOk {
-						return nil, fmt.Errorf("dynamic include: must be string, got %#v", s)
-					}
-					q, err = gojq.Parse(s)
-					if err != nil {
-						p := queryErrorPosition(s, err)
-						return nil, compileError{
-							err:      err,
-							what:     "parse",
-							filename: filenamePart,
-							pos:      p,
-						}
-					}
-				}
-
-				// TODO: some better way of handling relative includes that
-				// works with @builtin etc
-				basePath := filepath.Dir(name)
-				for _, i := range q.Imports {
-					rewritePath := func(base, path string) string {
-						if strings.HasPrefix(i.IncludePath, "@") {
-							return path
-						}
-						if filepath.IsAbs(i.IncludePath) {
-							return path
-						}
-						return filepath.Join(base, path)
-					}
-					i.IncludePath = rewritePath(basePath, i.IncludePath)
-					i.ImportPath = rewritePath(basePath, i.ImportPath)
-				}
-
-				i.includeCache[filename] = q
-
-				return q, nil
 			}
 
-			panic("unreachable")
+			// TODO: some better way of handling relative includes that
+			// works with @builtin etc
+			basePath := path.Dir(name)
+			for _, qi := range q.Imports {
+				rewritePath := func(base, includePath string) string {
+					if strings.HasPrefix(includePath, "@") || path.IsAbs(includePath) {
+						return includePath
+					}
+
+					return path.Join(base, includePath)
+				}
+				if qi.IncludePath != "" {
+					qi.IncludePath = rewritePath(basePath, qi.IncludePath)
+				}
+				if qi.ImportPath != "" {
+					qi.ImportPath = rewritePath(basePath, qi.ImportPath)
+				}
+			}
+
+			i.includeCache[filename] = q
+
+			return q, nil
 		},
 	}))
 
